# Release History

## 8.0.0b3 (2026-06-10)

### Features Added

  - Client `MonitorManagementClient` added method `send_request`
  - Client `MonitorManagementClient` added operation group `scheduled_query_rule`
  - Model `ActionGroup` added property `action_properties`
  - Model `ActionGroupPatchBody` added property `identity`
  - Model `ActionGroupResource` added property `identity`
  - Model `ActionGroupResource` added property `system_data`
  - Model `ActivityLogAlertResource` added property `system_data`
  - Model `AutomationRunbookReceiver` added property `managed_identity`
  - Model `AutoscaleNotification` added property `operation`
  - Model `AzureFunctionReceiver` added property `managed_identity`
  - Model `AzureMonitorPrivateLinkScope` added property `system_data`
  - Model `Condition` added property `criterion_type`
  - Model `Condition` added property `alert_sensitivity`
  - Model `Condition` added property `ignore_data_before`
  - Model `Condition` added property `min_recurrence_count`
  - Enum `ConditionOperator` added member `GREATER_OR_LESS_THAN`
  - Model `DataCollectionEndpointResource` added property `sku`
  - Model `DataCollectionRule` added property `direct_data_sources`
  - Model `DataCollectionRule` added property `ingestion_quotas`
  - Model `DataCollectionRuleDataSources` added property `performance_counters_o_tel`
  - Model `DataCollectionRuleDataSources` added property `otel_logs`
  - Model `DataCollectionRuleDataSources` added property `otel_traces`
  - Model `DataCollectionRuleDataSources` added property `otel_metrics`
  - Model `DataCollectionRuleDataSources` added property `etw_providers`
  - Model `DataCollectionRuleReferences` added property `application_insights`
  - Model `DataCollectionRuleResource` added property `sku`
  - Model `DataCollectionRuleResourceProperties` added property `direct_data_sources`
  - Model `DataCollectionRuleResourceProperties` added property `ingestion_quotas`
  - Model `DataSourcesSpec` added property `performance_counters_o_tel`
  - Model `DataSourcesSpec` added property `otel_logs`
  - Model `DataSourcesSpec` added property `otel_traces`
  - Model `DataSourcesSpec` added property `otel_metrics`
  - Model `DataSourcesSpec` added property `etw_providers`
  - Model `ErrorDetailAutoGenerated` added property `details`
  - Model `ErrorResponseCommon` added property `target`
  - Model `EventHubReceiver` added property `managed_identity`
  - Enum `Kind` added member `SIMPLE_LOG_ALERT`
  - Enum `KnownAgentSettingName` added member `TAGS`
  - Model `LogProfileResource` added property `system_data`
  - Model `LogicAppReceiver` added property `managed_identity`
  - Model `MetricAlertResource` added property `system_data`
  - Model `NotificationRequestBody` added property `incident_receivers`
  - Model `PrivateEndpointConnection` added property `system_data`
  - Model `PrivateLinkResource` added property `system_data`
  - Model `PrometheusForwarderDataSource` added property `custom_vm_scrape_config`
  - Model `ProxyResource` added property `system_data`
  - Model `ReferencesSpec` added property `application_insights`
  - Model `ScopedResource` added property `system_data`
  - Model `ServiceDiagnosticSettingsResource` added property `system_data`
  - Model `WebhookReceiver` added property `managed_identity`
  - Added enum `AccessMode`
  - Added model `AccessModeSettings`
  - Added model `AccessModeSettingsExclusion`
  - Added model `AccessRule`
  - Added enum `AccessRuleDirection`
  - Added model `AccessRuleProperties`
  - Added model `AccessRulePropertiesSubscription`
  - Added model `ActivityLogAlertErrorResponse`
  - Added model `ApplicationInsights`
  - Added model `DataCollectionEndpointResourceSku`
  - Added model `DataCollectionRuleDirectDataSources`
  - Added model `DataCollectionRuleIngestionQuotas`
  - Added model `DataCollectionRuleResourceSku`
  - Added model `DirectDataSourcesSpec`
  - Added model `EtwProviderDataSource`
  - Added model `ExtensionResource`
  - Added enum `IncidentManagementService`
  - Added model `IncidentReceiver`
  - Added model `IncidentServiceConnection`
  - Added model `IngestionQuotas`
  - Added model `IngestionQuotasLogs`
  - Added enum `IssueType`
  - Added enum `KnownEtwProviderDataSourceLogLevel`
  - Added enum `KnownEtwProviderType`
  - Added enum `KnownOtelLogsDataSourceStreams`
  - Added enum `KnownOtelLogsDirectDataSourceStreams`
  - Added enum `KnownOtelTracesDataSourceStreams`
  - Added enum `KnownOtelTracesDirectDataSourceStreams`
  - Added enum `KnownPerformanceCountersOTelDataSourceStreams`
  - Added model `LogsQuotaSpec`
  - Added model `MetricAlertErrorResponse`
  - Added model `MetricBaselinesErrorResponse`
  - Added model `NetworkSecurityPerimeter`
  - Added model `NetworkSecurityPerimeterConfiguration`
  - Added model `NetworkSecurityPerimeterConfigurationProperties`
  - Added enum `NetworkSecurityPerimeterConfigurationProvisioningState`
  - Added model `NetworkSecurityProfile`
  - Added enum `OperationType`
  - Added model `OtelDataSourceResourceAttributeRouting`
  - Added model `OtelLogsDataSource`
  - Added model `OtelLogsDataSourceResourceAttributeRouting`
  - Added model `OtelLogsDirectDataSource`
  - Added model `OtelMetricsDataSource`
  - Added model `OtelMetricsDataSourceResourceAttributeRouting`
  - Added model `OtelMetricsDirectDataSource`
  - Added model `OtelTracesDataSource`
  - Added model `OtelTracesDataSourceResourceAttributeRouting`
  - Added model `OtelTracesDirectDataSource`
  - Added model `PerformanceCountersOTelDataSource`
  - Added enum `PrivateLinkScopeProvisioningState`
  - Added model `ProvisioningIssue`
  - Added model `ProvisioningIssueProperties`
  - Added model `ResourceAssociation`
  - Added enum `ResourceAssociationAccessMode`
  - Added enum `ScopedResourceKind`
  - Added enum `ScopedResourceProvisioningState`
  - Added enum `Severity`
  - Added model `Sku`
  - Added enum `SkuTier`
  - Operation group `ActionGroupsOperations` added method `begin_reconcile_nsp`
  - Operation group `ActionGroupsOperations` added method `get_nsp`
  - Operation group `ActionGroupsOperations` added method `list_nsp`
  - Operation group `DataCollectionEndpointsOperations` added method `begin_reconcile_nsp`
  - Operation group `DataCollectionEndpointsOperations` added method `get_nsp`
  - Operation group `DataCollectionEndpointsOperations` added method `list_nsp`
  - Operation group `DataCollectionRuleAssociationsOperations` added parameter `skip_token` in method `list_by_rule`
  - Operation group `DataCollectionRuleAssociationsOperations` added parameter `top` in method `list_by_rule`
  - Operation group `PrivateLinkScopedResourcesOperations` added parameter `kind` in method `list_by_private_link_scope`

### Breaking Changes

  - This version introduces new hybrid models which have dual dictionary and model nature. Please follow https://aka.ms/azsdk/python/migrate/hybrid-models for migration.
  - For the method breakings, please refer to https://aka.ms/azsdk/python/migrate/operations for migration.
  - Deleted or renamed client operation group `MonitorManagementClient.diagnostic_settings`
  - Deleted or renamed client operation group `MonitorManagementClient.diagnostic_settings_category`
  - Deleted or renamed client operation group `MonitorManagementClient.guest_diagnostics_settings`
  - Deleted or renamed client operation group `MonitorManagementClient.guest_diagnostics_settings_association`
  - Deleted or renamed client operation group `MonitorManagementClient.operations`
  - Deleted or renamed client operation group `MonitorManagementClient.vm_insights`
  - Deleted or renamed client operation group `MonitorManagementClient.subscription_diagnostic_settings`
  - Deleted or renamed client operation group `MonitorManagementClient.azure_monitor_workspaces`
  - Deleted or renamed client operation group `MonitorManagementClient.monitor_operations`
  - Model `ActionGroupPatchBody` moved instance variable `enabled` under property `properties` whose type is `ActionGroupPatch`
  - Model `ActivityLogAlertResource` moved instance variable `scopes`, `condition`, `actions`, `enabled` and `description` under property `properties` whose type is `AlertRuleProperties`
  - Model `AlertRulePatchObject` moved instance variable `enabled` under property `properties` whose type is `AlertRulePatchProperties`
  - Model `AutoscaleSettingResource` moved instance variable `profiles`, `notifications`, `enabled`, `predictive_autoscale_policy`, `name_properties_name`, `target_resource_uri` and `target_resource_location` under property `properties` whose type is `AutoscaleSetting`
  - Model `AutoscaleSettingResourcePatch` moved instance variable `profiles`, `notifications`, `enabled`, `predictive_autoscale_policy`, `name`, `target_resource_uri` and `target_resource_location` under property `properties` whose type is `AutoscaleSetting`
  - Model `DataCollectionEndpointResource` moved instance variable `description`, `immutable_id`, `configuration_access`, `logs_ingestion`, `metrics_ingestion`, `network_acls`, `provisioning_state`, `private_link_scoped_resources`, `failover_configuration` and `metadata` under property `properties` whose type is `DataCollectionEndpointResourceProperties`
  - Model `DataCollectionRuleAssociationProxyOnlyResource` moved instance variable `description`, `data_collection_rule_id`, `data_collection_endpoint_id`, `provisioning_state` and `metadata` under property `properties` whose type is `DataCollectionRuleAssociationProxyOnlyResourceProperties`
  - Model `DataCollectionRuleResource` moved instance variable `description`, `immutable_id`, `data_collection_endpoint_id`, `metadata`, `endpoints`, `references`, `agent_settings`, `stream_declarations`, `data_sources`, `destinations`, `data_flows` and `provisioning_state` under property `properties` whose type is `DataCollectionRuleResourceProperties`
  - Model `ErrorResponseAutoGenerated` moved instance variable `code` and `message` under property `error` whose type is `ErrorDetailAutoGenerated`
  - Model `LogProfileResource` moved instance variable `storage_account_id`, `service_bus_rule_id`, `locations`, `categories` and `retention_policy` under property `properties` whose type is `LogProfileProperties`
  - Model `LogProfileResourcePatch` moved instance variable `storage_account_id`, `service_bus_rule_id`, `locations`, `categories` and `retention_policy` under property `properties` whose type is `LogProfileProperties`
  - Model `MetricAlertResource` moved instance variable `description`, `severity`, `enabled`, `scopes`, `evaluation_frequency`, `window_size`, `target_resource_type`, `target_resource_region`, `criteria`, `auto_mitigate`, `resolve_configuration`, `actions`, `last_updated_time`, `is_migrated`, `custom_properties` and `action_properties` under property `properties` whose type is `MetricAlertProperties`
  - Model `MetricAlertResourcePatch` moved instance variable `description`, `severity`, `enabled`, `scopes`, `evaluation_frequency`, `window_size`, `target_resource_type`, `target_resource_region`, `criteria`, `auto_mitigate`, `resolve_configuration`, `actions`, `last_updated_time`, `is_migrated`, `custom_properties` and `action_properties` under property `properties` whose type is `MetricAlertPropertiesPatch`
  - Model `ScheduledQueryRuleResource` moved instance variable `created_with_api_version`, `is_legacy_log_analytics_rule`, `description`, `display_name`, `severity`, `enabled`, `scopes`, `evaluation_frequency`, `window_size`, `override_query_time_range`, `target_resource_types`, `criteria`, `mute_actions_duration`, `actions`, `is_workspace_alerts_storage_configured`, `check_workspace_alerts_storage_configured`, `skip_query_validation`, `auto_mitigate` and `resolve_configuration` under property `properties` whose type is `ScheduledQueryRuleProperties`
  - Model `ScheduledQueryRuleResourcePatch` moved instance variable `created_with_api_version`, `is_legacy_log_analytics_rule`, `description`, `display_name`, `severity`, `enabled`, `scopes`, `evaluation_frequency`, `window_size`, `override_query_time_range`, `target_resource_types`, `criteria`, `mute_actions_duration`, `actions`, `is_workspace_alerts_storage_configured`, `check_workspace_alerts_storage_configured`, `skip_query_validation`, `auto_mitigate` and `resolve_configuration` under property `properties` whose type is `ScheduledQueryRuleProperties`
  - Model `ServiceDiagnosticSettingsResource` moved instance variable `storage_account_id`, `service_bus_rule_id`, `event_hub_authorization_rule_id`, `metrics`, `logs` and `workspace_id` under property `properties` whose type is `ServiceDiagnosticSettings`
  - Model `ServiceDiagnosticSettingsResourcePatch` moved instance variable `storage_account_id`, `service_bus_rule_id`, `event_hub_authorization_rule_id`, `metrics`, `logs` and `workspace_id` under property `properties` whose type is `ServiceDiagnosticSettings`
  - Model `SingleMetricBaseline` moved instance variable `timespan`, `interval`, `namespace` and `baselines` under property `properties` whose type is `MetricBaselinesProperties`
  - Model `Dimension`/`MetricDimension`/`ScaleRuleMetricDimension` renamed its instance variable `values` to `values_property`
  - Model `Resource` deleted or renamed its instance variable `location` and `tags`
  - Method `ActivityLogsOperations.list` changed its parameter `select` from `positional_or_keyword` to `keyword_only`
  - Method `BaselinesOperations.list` changed its parameter `metricnames`/`metricnamespace`/`timespan`/`interval`/`aggregation`/`sensitivities`/`result_type` from `positional_or_keyword` to `keyword_only`
  - Method `DataCollectionRulesOperations.delete` changed its parameter `delete_associations` from `positional_or_keyword` to `keyword_only`
  - Method `MetricDefinitionsOperations.list` changed its parameter `metricnamespace` from `positional_or_keyword` to `keyword_only`
  - Method `MetricDefinitionsOperations.list_at_subscription_scope` changed its parameter `region`/`metricnamespace` from `positional_or_keyword` to `keyword_only`
  - Method `MetricNamespacesOperations.list` changed its parameter `start_time` from `positional_or_keyword` to `keyword_only`
  - Method `MetricsOperations.list` changed its parameter `timespan`/`interval`/`metricnames`/`aggregation`/`orderby`/`result_type`/`metricnamespace`/`auto_adjust_timegrain`/`validate_dimensions`/`rollupby` from `positional_or_keyword` to `keyword_only`
  - Method `MetricsOperations.list_at_subscription_scope` changed its parameter `region`/`timespan`/`interval`/`metricnames`/`aggregation`/`orderby`/`result_type`/`metricnamespace`/`auto_adjust_timegrain`/`validate_dimensions`/`rollupby` from `positional_or_keyword` to `keyword_only`
  - Method `MetricsOperations.list_at_subscription_scope_post` changed its parameter `region`/`timespan`/`interval`/`metricnames`/`aggregation`/`orderby`/`result_type`/`metricnamespace`/`auto_adjust_timegrain`/`validate_dimensions`/`rollupby` from `positional_or_keyword` to `keyword_only`
  - Method `PredictiveMetricOperations.get` changed its parameter `timespan`/`interval`/`metric_namespace`/`metric_name`/`aggregation` from `positional_or_keyword` to `keyword_only`
  - Method `TenantActivityLogsOperations.list` changed its parameter `select` from `positional_or_keyword` to `keyword_only`

### Other Changes

  - Deleted model `ActionGroupList`/`AlertRuleList`/`AutoscaleSettingResourceCollection`/`DiagnosticSettingsCategoryResourceCollection`/`DiagnosticSettingsResourceCollection`/`EventCategoryCollection`/`EventDataCollection`/`GuestDiagnosticSettingsAssociationList`/`GuestDiagnosticSettingsList`/`LogProfileCollection`/`MetricAlertResourceCollection`/`MetricBaselinesResponse`/`MetricDefinitionCollection`/`MetricNamespaceCollection`/`OperationListResultAutoGenerated`/`ScheduledQueryRuleResourceCollection`/`SubscriptionDiagnosticSettingsResourceCollection`/`SubscriptionScopeMetricDefinitionCollection` which actually were not used by SDK users
  - Deleted model `AzureMonitorWorkspace`/`AzureMonitorWorkspaceDefaultIngestionSettings`/`AzureMonitorWorkspaceMetrics`/`AzureMonitorWorkspaceResource`/`AzureMonitorWorkspaceResourceForUpdate`/`AzureMonitorWorkspaceResourceProperties`/`AzureResource`/`AzureResourceAutoGenerated`/`DataCollectionEndpointResourceSystemData`/`DataCollectionRuleAssociationProxyOnlyResourceSystemData`/`DataCollectionRuleResourceSystemData`/`DataContainer`/`DataSource`/`DataSourceConfiguration`/`DiagnosticSettingsCategoryResource`/`DiagnosticSettingsResource`/`Error`/`ErrorDetailAdditionalInfoItemAutoGenerated`/`ErrorDetailAutoGenerated2`/`ErrorDetailAutoGenerated3`/`ErrorResponseAutoGenerated2`/`ErrorResponseAutoGenerated3`/`ErrorResponseAutoGenerated4`/`ErrorResponseAutoGenerated5`/`ErrorResponseErrorAdditionalInfoItemAutoGenerated`/`ErrorResponseErrorAutoGenerated`/`EtwEventConfiguration`/`EtwProviderConfiguration`/`EventLogConfiguration`/`GuestDiagnosticSettingsAssociationResource`/`GuestDiagnosticSettingsAssociationResourcePatch`/`GuestDiagnosticSettingsPatchResource`/`GuestDiagnosticSettingsResource`/`IdentityAutoGenerated`/`IngestionSettings`/`LocalizableStringAutoGenerated`/`LogSettingsAutoGenerated`/`MetricSettingsAutoGenerated`/`Metrics`/`Operation`/`OperationAutoGenerated`/`OperationDisplay`/`OperationDisplayAutoGenerated`/`PerformanceCounterConfiguration`/`PrivateEndpointConnectionAutoGenerated`/`PrivateEndpointProperty`/`PrivateLinkScopesResource`/`PrivateLinkServiceConnectionStateProperty`/`ProxyOnlyResource`/`ResourceAutoGenerated`/`ResourceAutoGenerated2`/`ResourceAutoGenerated3`/`ResourceAutoGenerated4`/`ResourceAutoGenerated5`/`ResourceAutoGenerated6`/`ResourceAutoGenerated7`/`ResourceAutoGenerated8`/`ResponseWithError`/`SinkConfiguration`/`SubscriptionDiagnosticSettingsResource`/`SubscriptionLogSettings`/`SubscriptionProxyOnlyResource`/`UserIdentityPropertiesAutoGenerated`/`VMInsightsOnboardingStatus`/`WorkspaceInfo` which actually were not used by SDK users
  - Deleted enum `ActionType`/`CategoryType`/`DataSourceKind`/`DataStatus`/`GuestDiagnosticSettingsOsType`/`OnboardingStatus`/`Origin`/`ProvisioningState`/`PublicNetworkAccess`/`SinkConfigurationKind` which actually were not used by SDK users
  - Parameter `delete_associations` of `DataCollectionRulesOperations.delete` is now optional

## 8.0.0b2 (2025-11-16)

### Features Added

  - Model `MonitorManagementClient` added parameter `cloud_setting` in method `__init__`
  - Model `MetricAlertResource` added property `resolve_configuration`
  - Model `MetricAlertResource` added property `custom_properties`
  - Model `MetricAlertResource` added property `action_properties`
  - Model `MetricAlertResource` added property `identity`
  - Model `MetricAlertResourcePatch` added property `identity`
  - Model `MetricAlertResourcePatch` added property `resolve_configuration`
  - Model `MetricAlertResourcePatch` added property `custom_properties`
  - Model `MetricAlertResourcePatch` added property `action_properties`
  - Enum `Odatatype` added member `MICROSOFT_AZURE_MONITOR_PROM_QL_CRITERIA`
  - Model `ResourceAutoGenerated5` added property `identity`
  - Added model `DynamicPromQLCriteria`
  - Added model `ErrorDetailAdditionalInfoItemAutoGenerated`
  - Added model `ErrorDetailAutoGenerated3`
  - Added model `ErrorResponseErrorAdditionalInfoItemAutoGenerated`
  - Added model `ErrorResponseErrorAutoGenerated`
  - Added model `IdentityAutoGenerated`
  - Added model `MultiPromQLCriteria`
  - Added model `PromQLCriteria`
  - Added model `QueryFailingPeriods`
  - Added model `ResolveConfiguration`
  - Added model `StaticPromQLCriteria`
  - Added model `UserIdentityPropertiesAutoGenerated`

### Breaking Changes

  - Model `ErrorDetailAutoGenerated` deleted or renamed its instance variable `details`

## 8.0.0b1 (2025-08-05)

### Features Added

  - Client `MonitorManagementClient` added operation group `diagnostic_settings`
  - Client `MonitorManagementClient` added operation group `diagnostic_settings_category`
  - Client `MonitorManagementClient` added operation group `guest_diagnostics_settings`
  - Client `MonitorManagementClient` added operation group `guest_diagnostics_settings_association`
  - Client `MonitorManagementClient` added operation group `service_diagnostic_settings`
  - Client `MonitorManagementClient` added operation group `vm_insights`
  - Client `MonitorManagementClient` added operation group `private_link_scopes`
  - Client `MonitorManagementClient` added operation group `private_link_scope_operation_status`
  - Client `MonitorManagementClient` added operation group `private_link_resources`
  - Client `MonitorManagementClient` added operation group `private_endpoint_connections`
  - Client `MonitorManagementClient` added operation group `private_link_scoped_resources`
  - Client `MonitorManagementClient` added operation group `subscription_diagnostic_settings`
  - Model `ErrorDetailAutoGenerated` added property `details`
  - Model `ResourceAutoGenerated3` added property `location`
  - Model `ResourceAutoGenerated3` added property `tags`
  - Model `ResourceAutoGenerated4` added property `location`
  - Model `ResourceAutoGenerated4` added property `tags`
  - Added model `AzureMonitorPrivateLinkScope`
  - Added model `AzureMonitorPrivateLinkScopeListResult`
  - Added enum `CategoryType`
  - Added model `DataContainer`
  - Added model `DataSource`
  - Added model `DataSourceConfiguration`
  - Added enum `DataSourceKind`
  - Added enum `DataStatus`
  - Added model `DiagnosticSettingsCategoryResource`
  - Added model `DiagnosticSettingsCategoryResourceCollection`
  - Added model `DiagnosticSettingsResource`
  - Added model `DiagnosticSettingsResourceCollection`
  - Added model `Error`
  - Added model `ErrorResponseCommon`
  - Added model `EtwEventConfiguration`
  - Added model `EtwProviderConfiguration`
  - Added model `EventLogConfiguration`
  - Added model `GuestDiagnosticSettingsAssociationList`
  - Added model `GuestDiagnosticSettingsAssociationResource`
  - Added model `GuestDiagnosticSettingsAssociationResourcePatch`
  - Added model `GuestDiagnosticSettingsList`
  - Added enum `GuestDiagnosticSettingsOsType`
  - Added model `GuestDiagnosticSettingsPatchResource`
  - Added model `GuestDiagnosticSettingsResource`
  - Added model `LogSettings`
  - Added model `LogSettingsAutoGenerated`
  - Added model `MetricSettings`
  - Added model `MetricSettingsAutoGenerated`
  - Added enum `OnboardingStatus`
  - Added model `OperationStatus`
  - Added model `PerformanceCounterConfiguration`
  - Added model `PrivateEndpointConnectionAutoGenerated`
  - Added model `PrivateEndpointConnectionListResult`
  - Added model `PrivateEndpointProperty`
  - Added model `PrivateLinkResource`
  - Added model `PrivateLinkResourceListResult`
  - Added model `PrivateLinkScopesResource`
  - Added model `PrivateLinkServiceConnectionStateProperty`
  - Added model `ProxyOnlyResource`
  - Added model `ProxyResource`
  - Added model `ResourceAutoGenerated5`
  - Added model `ResourceAutoGenerated6`
  - Added model `ResourceAutoGenerated7`
  - Added model `ResourceAutoGenerated8`
  - Added model `ResponseWithError`
  - Added model `ScopedResource`
  - Added model `ScopedResourceListResult`
  - Added model `ServiceDiagnosticSettingsResource`
  - Added model `ServiceDiagnosticSettingsResourcePatch`
  - Added model `SinkConfiguration`
  - Added enum `SinkConfigurationKind`
  - Added model `SubscriptionDiagnosticSettingsResource`
  - Added model `SubscriptionDiagnosticSettingsResourceCollection`
  - Added model `SubscriptionLogSettings`
  - Added model `SubscriptionProxyOnlyResource`
  - Added model `TagsResource`
  - Added model `VMInsightsOnboardingStatus`
  - Added model `WorkspaceInfo`
  - Added operation group `DiagnosticSettingsCategoryOperations`
  - Added operation group `DiagnosticSettingsOperations`
  - Added operation group `GuestDiagnosticsSettingsAssociationOperations`
  - Added operation group `GuestDiagnosticsSettingsOperations`
  - Added operation group `PrivateEndpointConnectionsOperations`
  - Added operation group `PrivateLinkResourcesOperations`
  - Added operation group `PrivateLinkScopeOperationStatusOperations`
  - Added operation group `PrivateLinkScopedResourcesOperations`
  - Added operation group `PrivateLinkScopesOperations`
  - Added operation group `ServiceDiagnosticSettingsOperations`
  - Added operation group `SubscriptionDiagnosticSettingsOperations`
  - Added operation group `VMInsightsOperations`

### Breaking Changes

  - Model `ErrorDetail` deleted or renamed its instance variable `details`
  - Model `PrivateEndpointConnection` deleted or renamed its instance variable `group_ids`
  - Model `PrivateEndpointConnection` deleted or renamed its instance variable `system_data`
  - Model `ResourceAutoGenerated` deleted or renamed its instance variable `location`
  - Model `ResourceAutoGenerated` deleted or renamed its instance variable `tags`
  - Model `ResourceAutoGenerated3` deleted or renamed its instance variable `system_data`
  - Model `ResourceAutoGenerated4` deleted or renamed its instance variable `system_data`

## 7.0.0 (2025-07-28)

### Features Added

  - Client `MonitorManagementClient` added operation group `action_groups`
  - Client `MonitorManagementClient` added operation group `activity_log_alerts`
  - Client `MonitorManagementClient` added operation group `activity_logs`
  - Client `MonitorManagementClient` added operation group `alert_rule_incidents`
  - Client `MonitorManagementClient` added operation group `autoscale_settings`
  - Client `MonitorManagementClient` added operation group `predictive_metric`
  - Client `MonitorManagementClient` added operation group `data_collection_endpoints`
  - Client `MonitorManagementClient` added operation group `data_collection_rule_associations`
  - Client `MonitorManagementClient` added operation group `data_collection_rules`
  - Client `MonitorManagementClient` added operation group `event_categories`
  - Client `MonitorManagementClient` added operation group `log_profiles`
  - Client `MonitorManagementClient` added operation group `metric_alerts`
  - Client `MonitorManagementClient` added operation group `metric_alerts_status`
  - Client `MonitorManagementClient` added operation group `baselines`
  - Client `MonitorManagementClient` added operation group `metric_definitions`
  - Client `MonitorManagementClient` added operation group `metric_namespaces`
  - Client `MonitorManagementClient` added operation group `metrics`
  - Client `MonitorManagementClient` added operation group `operations`
  - Client `MonitorManagementClient` added operation group `scheduled_query_rules`
  - Client `MonitorManagementClient` added operation group `tenant_activity_logs`
  - Client `MonitorManagementClient` added operation group `azure_monitor_workspaces`
  - Client `MonitorManagementClient` added operation group `monitor_operations`
  - Added model `ActionDetail`
  - Added model `ActionGroup`
  - Added model `ActionGroupList`
  - Added model `ActionGroupResource`
  - Added model `ActionList`
  - Added enum `ActionType`
  - Added model `Actions`
  - Added model `ActivityLogAlertResource`
  - Added model `AdxDestination`
  - Added model `AgentSetting`
  - Added model `AgentSettingsSpec`
  - Added enum `AggregationType`
  - Added enum `AggregationTypeEnum`
  - Added model `AlertRuleAllOfCondition`
  - Added model `AlertRuleAnyOfOrLeafCondition`
  - Added model `AlertRuleLeafCondition`
  - Added model `AlertRuleList`
  - Added model `AlertRulePatchObject`
  - Added enum `AlertSeverity`
  - Added model `ArmRoleReceiver`
  - Added model `AutomationRunbookReceiver`
  - Added model `AutoscaleErrorResponse`
  - Added model `AutoscaleErrorResponseError`
  - Added model `AutoscaleNotification`
  - Added model `AutoscaleProfile`
  - Added model `AutoscaleSettingResource`
  - Added model `AutoscaleSettingResourceCollection`
  - Added model `AutoscaleSettingResourcePatch`
  - Added model `AzureFunctionReceiver`
  - Added model `AzureMonitorMetricsDestination`
  - Added model `AzureMonitorWorkspace`
  - Added model `AzureMonitorWorkspaceDefaultIngestionSettings`
  - Added model `AzureMonitorWorkspaceMetrics`
  - Added model `AzureMonitorWorkspaceResource`
  - Added model `AzureMonitorWorkspaceResourceForUpdate`
  - Added model `AzureMonitorWorkspaceResourceListResult`
  - Added model `AzureMonitorWorkspaceResourceProperties`
  - Added model `AzureResourceAutoGenerated`
  - Added model `BaselineMetadata`
  - Added enum `BaselineSensitivity`
  - Added model `ColumnDefinition`
  - Added enum `ComparisonOperationType`
  - Added model `Condition`
  - Added model `ConditionFailingPeriods`
  - Added enum `ConditionOperator`
  - Added model `ConfigurationAccessEndpointSpec`
  - Added model `Context`
  - Added enum `CreatedByType`
  - Added enum `CriterionType`
  - Added model `DataCollectionEndpoint`
  - Added model `DataCollectionEndpointConfigurationAccess`
  - Added model `DataCollectionEndpointFailoverConfiguration`
  - Added model `DataCollectionEndpointLogsIngestion`
  - Added model `DataCollectionEndpointMetadata`
  - Added model `DataCollectionEndpointMetricsIngestion`
  - Added model `DataCollectionEndpointNetworkAcls`
  - Added model `DataCollectionEndpointResource`
  - Added model `DataCollectionEndpointResourceIdentity`
  - Added model `DataCollectionEndpointResourceListResult`
  - Added model `DataCollectionEndpointResourceProperties`
  - Added model `DataCollectionEndpointResourceSystemData`
  - Added model `DataCollectionRule`
  - Added model `DataCollectionRuleAgentSettings`
  - Added model `DataCollectionRuleAssociation`
  - Added model `DataCollectionRuleAssociationMetadata`
  - Added model `DataCollectionRuleAssociationProxyOnlyResource`
  - Added model `DataCollectionRuleAssociationProxyOnlyResourceListResult`
  - Added model `DataCollectionRuleAssociationProxyOnlyResourceProperties`
  - Added model `DataCollectionRuleAssociationProxyOnlyResourceSystemData`
  - Added model `DataCollectionRuleDataSources`
  - Added model `DataCollectionRuleDestinations`
  - Added model `DataCollectionRuleEndpoints`
  - Added model `DataCollectionRuleMetadata`
  - Added model `DataCollectionRuleReferences`
  - Added model `DataCollectionRuleResource`
  - Added model `DataCollectionRuleResourceIdentity`
  - Added model `DataCollectionRuleResourceListResult`
  - Added model `DataCollectionRuleResourceProperties`
  - Added model `DataCollectionRuleResourceSystemData`
  - Added model `DataFlow`
  - Added model `DataImportSources`
  - Added model `DataImportSourcesEventHub`
  - Added model `DataSourcesSpec`
  - Added model `DataSourcesSpecDataImports`
  - Added model `DestinationsSpec`
  - Added model `DestinationsSpecAzureMonitorMetrics`
  - Added model `Dimension`
  - Added enum `DimensionOperator`
  - Added model `DynamicMetricCriteria`
  - Added model `DynamicThresholdFailingPeriods`
  - Added enum `DynamicThresholdOperator`
  - Added enum `DynamicThresholdSensitivity`
  - Added model `EmailNotification`
  - Added model `EnableRequest`
  - Added model `EndpointsSpec`
  - Added model `EnrichmentData`
  - Added model `ErrorAdditionalInfo`
  - Added model `ErrorContract`
  - Added model `ErrorDetail`
  - Added model `ErrorDetailAdditionalInfoItem`
  - Added model `ErrorDetailAutoGenerated`
  - Added model `ErrorDetailAutoGenerated2`
  - Added model `ErrorResponseAutoGenerated`
  - Added model `ErrorResponseAutoGenerated2`
  - Added model `ErrorResponseAutoGenerated3`
  - Added model `ErrorResponseAutoGenerated4`
  - Added model `ErrorResponseAutoGenerated5`
  - Added model `ErrorResponseCommonV2`
  - Added model `ErrorResponseError`
  - Added model `ErrorResponseErrorAdditionalInfoItem`
  - Added model `EventCategoryCollection`
  - Added model `EventData`
  - Added model `EventDataCollection`
  - Added model `EventHubDataSource`
  - Added model `EventHubDestination`
  - Added model `EventHubDirectDestination`
  - Added model `EventHubReceiver`
  - Added enum `EventLevel`
  - Added model `ExtensionDataSource`
  - Added model `FailoverConfigurationSpec`
  - Added model `HttpRequestInfo`
  - Added model `Identity`
  - Added enum `IdentityType`
  - Added model `IisLogsDataSource`
  - Added model `Incident`
  - Added model `IncidentListResult`
  - Added model `IngestionSettings`
  - Added model `ItsmReceiver`
  - Added enum `Kind`
  - Added enum `KnownAgentSettingName`
  - Added enum `KnownColumnDefinitionType`
  - Added enum `KnownDataCollectionEndpointProvisioningState`
  - Added enum `KnownDataCollectionEndpointResourceKind`
  - Added enum `KnownDataCollectionRuleAssociationProvisioningState`
  - Added enum `KnownDataCollectionRuleProvisioningState`
  - Added enum `KnownDataCollectionRuleResourceKind`
  - Added enum `KnownDataFlowStreams`
  - Added enum `KnownExtensionDataSourceStreams`
  - Added enum `KnownLocationSpecProvisioningStatus`
  - Added enum `KnownLogFileTextSettingsRecordStartTimestampFormat`
  - Added enum `KnownLogFilesDataSourceFormat`
  - Added enum `KnownPerfCounterDataSourceStreams`
  - Added enum `KnownPrometheusForwarderDataSourceStreams`
  - Added enum `KnownPublicNetworkAccessOptions`
  - Added enum `KnownStorageBlobLookupType`
  - Added enum `KnownSyslogDataSourceFacilityNames`
  - Added enum `KnownSyslogDataSourceLogLevels`
  - Added enum `KnownSyslogDataSourceStreams`
  - Added enum `KnownWindowsEventLogDataSourceStreams`
  - Added enum `KnownWindowsFirewallLogsDataSourceProfileFilter`
  - Added model `LocalizableString`
  - Added model `LocalizableStringAutoGenerated`
  - Added model `LocationSpec`
  - Added model `LogAnalyticsDestination`
  - Added model `LogFileSettings`
  - Added model `LogFileSettingsText`
  - Added model `LogFileTextSettings`
  - Added model `LogFilesDataSource`
  - Added model `LogFilesDataSourceSettings`
  - Added model `LogProfileCollection`
  - Added model `LogProfileResource`
  - Added model `LogProfileResourcePatch`
  - Added model `LogicAppReceiver`
  - Added model `LogsIngestionEndpointSpec`
  - Added model `ManagedServiceIdentity`
  - Added enum `ManagedServiceIdentityType`
  - Added model `Metadata`
  - Added model `MetadataValue`
  - Added model `Metric`
  - Added enum `MetricAggregationType`
  - Added model `MetricAlertAction`
  - Added model `MetricAlertCriteria`
  - Added model `MetricAlertMultipleResourceMultipleMetricCriteria`
  - Added model `MetricAlertResource`
  - Added model `MetricAlertResourceCollection`
  - Added model `MetricAlertResourcePatch`
  - Added model `MetricAlertSingleResourceMultipleMetricCriteria`
  - Added model `MetricAlertStatus`
  - Added model `MetricAlertStatusCollection`
  - Added model `MetricAlertStatusProperties`
  - Added model `MetricAvailability`
  - Added model `MetricBaselinesResponse`
  - Added enum `MetricClass`
  - Added model `MetricCriteria`
  - Added model `MetricDefinition`
  - Added model `MetricDefinitionCollection`
  - Added model `MetricDimension`
  - Added model `MetricNamespace`
  - Added model `MetricNamespaceCollection`
  - Added model `MetricNamespaceName`
  - Added enum `MetricResultType`
  - Added model `MetricSingleDimension`
  - Added enum `MetricStatisticType`
  - Added model `MetricTrigger`
  - Added enum `MetricUnit`
  - Added model `MetricValue`
  - Added model `Metrics`
  - Added model `MetricsIngestionEndpointSpec`
  - Added model `MicrosoftFabricDestination`
  - Added model `MonitoringAccountDestination`
  - Added model `MultiMetricCriteria`
  - Added enum `NamespaceClassification`
  - Added model `NetworkRuleSet`
  - Added model `NotificationRequestBody`
  - Added enum `Odatatype`
  - Added model `Operation`
  - Added model `OperationAutoGenerated`
  - Added model `OperationDisplay`
  - Added model `OperationDisplayAutoGenerated`
  - Added model `OperationListResult`
  - Added model `OperationListResultAutoGenerated`
  - Added enum `Operator`
  - Added enum `Origin`
  - Added model `PerfCounterDataSource`
  - Added model `PlatformTelemetryDataSource`
  - Added model `PredictiveAutoscalePolicy`
  - Added enum `PredictiveAutoscalePolicyScaleMode`
  - Added model `PredictiveResponse`
  - Added model `PredictiveValue`
  - Added model `PrivateEndpoint`
  - Added model `PrivateEndpointConnection`
  - Added enum `PrivateEndpointConnectionProvisioningState`
  - Added enum `PrivateEndpointServiceConnectionStatus`
  - Added model `PrivateLinkScopedResource`
  - Added model `PrivateLinkServiceConnectionState`
  - Added model `PrometheusForwarderDataSource`
  - Added enum `ProvisioningState`
  - Added enum `PublicNetworkAccess`
  - Added model `Recurrence`
  - Added enum `RecurrenceFrequency`
  - Added model `RecurrentSchedule`
  - Added model `ReferencesSpec`
  - Added model `ReferencesSpecEnrichmentData`
  - Added model `Resource`
  - Added model `ResourceAutoGenerated`
  - Added model `ResourceAutoGenerated2`
  - Added model `ResourceAutoGenerated3`
  - Added model `ResourceAutoGenerated4`
  - Added model `ResourceForUpdate`
  - Added model `ResourceForUpdateIdentity`
  - Added model `Response`
  - Added enum `ResultType`
  - Added model `RetentionPolicy`
  - Added model `RuleResolveConfiguration`
  - Added model `ScaleAction`
  - Added model `ScaleCapacity`
  - Added enum `ScaleDirection`
  - Added model `ScaleRule`
  - Added model `ScaleRuleMetricDimension`
  - Added enum `ScaleRuleMetricDimensionOperationType`
  - Added enum `ScaleType`
  - Added model `ScheduledQueryRuleCriteria`
  - Added model `ScheduledQueryRuleResource`
  - Added model `ScheduledQueryRuleResourceCollection`
  - Added model `ScheduledQueryRuleResourcePatch`
  - Added model `SenderAuthorization`
  - Added model `SingleBaseline`
  - Added model `SingleMetricBaseline`
  - Added model `StorageBlob`
  - Added model `StorageBlobDestination`
  - Added model `StorageTableDestination`
  - Added model `StreamDeclaration`
  - Added model `SubscriptionScopeMetricDefinition`
  - Added model `SubscriptionScopeMetricDefinitionCollection`
  - Added model `SubscriptionScopeMetricsRequestBodyParameters`
  - Added model `SyslogDataSource`
  - Added model `SystemData`
  - Added model `TestNotificationDetailsResponse`
  - Added enum `TimeAggregation`
  - Added enum `TimeAggregationType`
  - Added model `TimeSeriesBaseline`
  - Added model `TimeSeriesElement`
  - Added model `TimeWindow`
  - Added model `TrackedResource`
  - Added model `UserAssignedIdentity`
  - Added model `UserIdentityProperties`
  - Added model `WebhookNotification`
  - Added model `WebtestLocationAvailabilityCriteria`
  - Added model `WindowsEventLogDataSource`
  - Added model `WindowsFirewallLogsDataSource`

### Breaking Changes

  - This package now only targets the latest Api-Version available on Azure and removes APIs of other Api-Version. After this change, the package can have much smaller size. If your application requires a specific and non-latest Api-Version, it's recommended to pin this package to the previous released version; If your application always only use latest Api-Version, please ignore this change.
  - Deleted or renamed client operation group `MonitorManagementClient.tenant_action_groups`
  - Parameter `subscription_id` of client `MonitorManagementClient` is now required
  - Deleted or renamed model `TenantActionGroupList`
  - Deleted or renamed model `TenantActionGroupResource`
  - Deleted or renamed operation group `TenantActionGroupsOperations`

## 7.0.0b3 (2025-07-21)

### Features Added

  - Client `MonitorManagementClient` added operation group `data_collection_endpoints`
  - Client `MonitorManagementClient` added operation group `data_collection_rule_associations`
  - Client `MonitorManagementClient` added operation group `data_collection_rules`
  - Added model `AdxDestination`
  - Added model `AgentSetting`
  - Added model `AgentSettingsSpec`
  - Added model `AzureMonitorMetricsDestination`
  - Added model `ColumnDefinition`
  - Added model `ConfigurationAccessEndpointSpec`
  - Added model `DataCollectionEndpoint`
  - Added model `DataCollectionEndpointConfigurationAccess`
  - Added model `DataCollectionEndpointFailoverConfiguration`
  - Added model `DataCollectionEndpointLogsIngestion`
  - Added model `DataCollectionEndpointMetadata`
  - Added model `DataCollectionEndpointMetricsIngestion`
  - Added model `DataCollectionEndpointNetworkAcls`
  - Added model `DataCollectionEndpointResource`
  - Added model `DataCollectionEndpointResourceIdentity`
  - Added model `DataCollectionEndpointResourceListResult`
  - Added model `DataCollectionEndpointResourceProperties`
  - Added model `DataCollectionEndpointResourceSystemData`
  - Added model `DataCollectionRule`
  - Added model `DataCollectionRuleAgentSettings`
  - Added model `DataCollectionRuleAssociation`
  - Added model `DataCollectionRuleAssociationMetadata`
  - Added model `DataCollectionRuleAssociationProxyOnlyResource`
  - Added model `DataCollectionRuleAssociationProxyOnlyResourceListResult`
  - Added model `DataCollectionRuleAssociationProxyOnlyResourceProperties`
  - Added model `DataCollectionRuleAssociationProxyOnlyResourceSystemData`
  - Added model `DataCollectionRuleDataSources`
  - Added model `DataCollectionRuleDestinations`
  - Added model `DataCollectionRuleEndpoints`
  - Added model `DataCollectionRuleMetadata`
  - Added model `DataCollectionRuleReferences`
  - Added model `DataCollectionRuleResource`
  - Added model `DataCollectionRuleResourceIdentity`
  - Added model `DataCollectionRuleResourceListResult`
  - Added model `DataCollectionRuleResourceProperties`
  - Added model `DataCollectionRuleResourceSystemData`
  - Added model `DataFlow`
  - Added model `DataImportSources`
  - Added model `DataImportSourcesEventHub`
  - Added model `DataSourcesSpec`
  - Added model `DataSourcesSpecDataImports`
  - Added model `DestinationsSpec`
  - Added model `DestinationsSpecAzureMonitorMetrics`
  - Added model `EndpointsSpec`
  - Added model `EnrichmentData`
  - Added model `ErrorDetailAutoGenerated2`
  - Added model `ErrorResponseCommonV2`
  - Added model `EventHubDataSource`
  - Added model `EventHubDestination`
  - Added model `EventHubDirectDestination`
  - Added model `ExtensionDataSource`
  - Added model `FailoverConfigurationSpec`
  - Added model `IisLogsDataSource`
  - Added enum `KnownAgentSettingName`
  - Added enum `KnownColumnDefinitionType`
  - Added enum `KnownDataCollectionEndpointProvisioningState`
  - Added enum `KnownDataCollectionEndpointResourceKind`
  - Added enum `KnownDataCollectionRuleAssociationProvisioningState`
  - Added enum `KnownDataCollectionRuleProvisioningState`
  - Added enum `KnownDataCollectionRuleResourceKind`
  - Added enum `KnownDataFlowStreams`
  - Added enum `KnownExtensionDataSourceStreams`
  - Added enum `KnownLocationSpecProvisioningStatus`
  - Added enum `KnownLogFileTextSettingsRecordStartTimestampFormat`
  - Added enum `KnownLogFilesDataSourceFormat`
  - Added enum `KnownPerfCounterDataSourceStreams`
  - Added enum `KnownPrometheusForwarderDataSourceStreams`
  - Added enum `KnownPublicNetworkAccessOptions`
  - Added enum `KnownStorageBlobLookupType`
  - Added enum `KnownSyslogDataSourceFacilityNames`
  - Added enum `KnownSyslogDataSourceLogLevels`
  - Added enum `KnownSyslogDataSourceStreams`
  - Added enum `KnownWindowsEventLogDataSourceStreams`
  - Added enum `KnownWindowsFirewallLogsDataSourceProfileFilter`
  - Added model `LocationSpec`
  - Added model `LogAnalyticsDestination`
  - Added model `LogFileSettings`
  - Added model `LogFileSettingsText`
  - Added model `LogFileTextSettings`
  - Added model `LogFilesDataSource`
  - Added model `LogFilesDataSourceSettings`
  - Added model `LogsIngestionEndpointSpec`
  - Added model `ManagedServiceIdentity`
  - Added enum `ManagedServiceIdentityType`
  - Added model `Metadata`
  - Added model `MetricsIngestionEndpointSpec`
  - Added model `MicrosoftFabricDestination`
  - Added model `MonitoringAccountDestination`
  - Added model `NetworkRuleSet`
  - Added model `PerfCounterDataSource`
  - Added model `PlatformTelemetryDataSource`
  - Added model `PrivateLinkScopedResource`
  - Added model `PrometheusForwarderDataSource`
  - Added model `ReferencesSpec`
  - Added model `ReferencesSpecEnrichmentData`
  - Added model `ResourceForUpdate`
  - Added model `ResourceForUpdateIdentity`
  - Added model `StorageBlob`
  - Added model `StorageBlobDestination`
  - Added model `StorageTableDestination`
  - Added model `StreamDeclaration`
  - Added model `SyslogDataSource`
  - Added model `UserAssignedIdentity`
  - Added model `WindowsEventLogDataSource`
  - Added model `WindowsFirewallLogsDataSource`
  - Added operation group `DataCollectionEndpointsOperations`
  - Added operation group `DataCollectionRuleAssociationsOperations`
  - Added operation group `DataCollectionRulesOperations`

## 7.0.0b2 (2025-06-16)

### Features Added

  - Client `MonitorManagementClient` added operation group `azure_monitor_workspaces`
  - Client `MonitorManagementClient` added operation group `monitor_operations`
  - Enum `ProvisioningState` added member `CREATING`
  - Enum `ProvisioningState` added member `DELETING`
  - Added enum `ActionType`
  - Added model `AzureMonitorWorkspace`
  - Added model `AzureMonitorWorkspaceDefaultIngestionSettings`
  - Added model `AzureMonitorWorkspaceMetrics`
  - Added model `AzureMonitorWorkspaceResource`
  - Added model `AzureMonitorWorkspaceResourceForUpdate`
  - Added model `AzureMonitorWorkspaceResourceListResult`
  - Added model `AzureMonitorWorkspaceResourceProperties`
  - Added model `ErrorDetailAutoGenerated`
  - Added model `ErrorResponseAutoGenerated3`
  - Added model `IngestionSettings`
  - Added model `Metrics`
  - Added model `OperationAutoGenerated`
  - Added model `OperationDisplayAutoGenerated`
  - Added model `OperationListResultAutoGenerated`
  - Added enum `Origin`
  - Added model `PrivateEndpoint`
  - Added model `PrivateEndpointConnectionAutoGenerated`
  - Added enum `PrivateEndpointConnectionProvisioningState`
  - Added enum `PrivateEndpointServiceConnectionStatus`
  - Added model `PrivateLinkServiceConnectionState`
  - Added enum `PublicNetworkAccess`
  - Added model `ResourceAutoGenerated4`
  - Added model `ResourceAutoGenerated5`
  - Added model `TrackedResource`
  - Added operation group `AzureMonitorWorkspacesOperations`
  - Added operation group `MonitorOperationsOperations`

## 7.0.0b1 (2025-02-08)

### Features Added

  - Client `MonitorManagementClient` added operation group `action_groups`
  - Client `MonitorManagementClient` added operation group `activity_log_alerts`
  - Client `MonitorManagementClient` added operation group `activity_logs`
  - Client `MonitorManagementClient` added operation group `tenant_activity_logs`
  - Client `MonitorManagementClient` added operation group `alert_rule_incidents`
  - Client `MonitorManagementClient` added operation group `autoscale_settings`
  - Client `MonitorManagementClient` added operation group `predictive_metric`
  - Client `MonitorManagementClient` added operation group `baselines`
  - Client `MonitorManagementClient` added operation group `diagnostic_settings`
  - Client `MonitorManagementClient` added operation group `diagnostic_settings_category`
  - Client `MonitorManagementClient` added operation group `event_categories`
  - Client `MonitorManagementClient` added operation group `guest_diagnostics_settings`
  - Client `MonitorManagementClient` added operation group `guest_diagnostics_settings_association`
  - Client `MonitorManagementClient` added operation group `log_profiles`
  - Client `MonitorManagementClient` added operation group `metric_alerts`
  - Client `MonitorManagementClient` added operation group `metric_alerts_status`
  - Client `MonitorManagementClient` added operation group `metric_definitions`
  - Client `MonitorManagementClient` added operation group `metric_namespaces`
  - Client `MonitorManagementClient` added operation group `metrics`
  - Client `MonitorManagementClient` added operation group `operations`
  - Client `MonitorManagementClient` added operation group `scheduled_query_rules`
  - Client `MonitorManagementClient` added operation group `service_diagnostic_settings`
  - Client `MonitorManagementClient` added operation group `vm_insights`
  - Client `MonitorManagementClient` added operation group `private_link_scopes`
  - Client `MonitorManagementClient` added operation group `private_link_scope_operation_status`
  - Client `MonitorManagementClient` added operation group `private_link_resources`
  - Client `MonitorManagementClient` added operation group `private_endpoint_connections`
  - Client `MonitorManagementClient` added operation group `private_link_scoped_resources`
  - Client `MonitorManagementClient` added operation group `subscription_diagnostic_settings`
  - Added model `Action`
  - Added model `ActionDetail`
  - Added model `ActionGroupList`
  - Added model `ActionGroupResource`
  - Added model `ActivityLogAlertActionGroup`
  - Added model `ActivityLogAlertActionList`
  - Added model `ActivityLogAlertAllOfCondition`
  - Added model `ActivityLogAlertLeafCondition`
  - Added model `ActivityLogAlertList`
  - Added model `ActivityLogAlertPatchBody`
  - Added model `ActivityLogAlertResource`
  - Added enum `AggregationType`
  - Added enum `AggregationTypeEnum`
  - Added enum `AlertSeverity`
  - Added model `AlertingAction`
  - Added model `ArmRoleReceiver`
  - Added model `AutomationRunbookReceiver`
  - Added model `AutoscaleErrorResponse`
  - Added model `AutoscaleErrorResponseError`
  - Added model `AutoscaleNotification`
  - Added model `AutoscaleProfile`
  - Added model `AutoscaleSettingResource`
  - Added model `AutoscaleSettingResourceCollection`
  - Added model `AutoscaleSettingResourcePatch`
  - Added model `AzNsActionGroup`
  - Added model `AzureFunctionReceiver`
  - Added model `AzureMonitorPrivateLinkScope`
  - Added model `AzureMonitorPrivateLinkScopeListResult`
  - Added model `BaselineMetadata`
  - Added enum `BaselineSensitivity`
  - Added enum `CategoryType`
  - Added enum `ComparisonOperationType`
  - Added enum `ConditionalOperator`
  - Added model `Context`
  - Added enum `CreatedByType`
  - Added model `Criteria`
  - Added enum `CriterionType`
  - Added model `DataContainer`
  - Added model `DataSource`
  - Added model `DataSourceConfiguration`
  - Added enum `DataSourceKind`
  - Added enum `DataStatus`
  - Added model `DiagnosticSettingsCategoryResource`
  - Added model `DiagnosticSettingsCategoryResourceCollection`
  - Added model `DiagnosticSettingsResource`
  - Added model `DiagnosticSettingsResourceCollection`
  - Added model `Dimension`
  - Added model `DynamicMetricCriteria`
  - Added model `DynamicThresholdFailingPeriods`
  - Added enum `DynamicThresholdOperator`
  - Added enum `DynamicThresholdSensitivity`
  - Added model `EmailNotification`
  - Added model `EnableRequest`
  - Added enum `Enabled`
  - Added model `Error`
  - Added model `ErrorAdditionalInfo`
  - Added model `ErrorContract`
  - Added model `ErrorDetail`
  - Added model `ErrorDetailAdditionalInfoItem`
  - Added model `ErrorResponseAutoGenerated`
  - Added model `ErrorResponseAutoGenerated2`
  - Added model `ErrorResponseCommon`
  - Added model `ErrorResponseError`
  - Added model `ErrorResponseErrorAdditionalInfoItem`
  - Added model `EtwEventConfiguration`
  - Added model `EtwProviderConfiguration`
  - Added model `EventCategoryCollection`
  - Added model `EventData`
  - Added model `EventDataCollection`
  - Added model `EventHubReceiver`
  - Added enum `EventLevel`
  - Added model `EventLogConfiguration`
  - Added model `GuestDiagnosticSettingsAssociationList`
  - Added model `GuestDiagnosticSettingsAssociationResource`
  - Added model `GuestDiagnosticSettingsAssociationResourcePatch`
  - Added model `GuestDiagnosticSettingsList`
  - Added enum `GuestDiagnosticSettingsOsType`
  - Added model `GuestDiagnosticSettingsPatchResource`
  - Added model `GuestDiagnosticSettingsResource`
  - Added model `HttpRequestInfo`
  - Added model `Incident`
  - Added model `IncidentListResult`
  - Added model `ItsmReceiver`
  - Added model `LocalizableString`
  - Added model `LocalizableStringAutoGenerated`
  - Added model `LogMetricTrigger`
  - Added model `LogProfileCollection`
  - Added model `LogProfileResource`
  - Added model `LogProfileResourcePatch`
  - Added model `LogSearchRuleResource`
  - Added model `LogSearchRuleResourceCollection`
  - Added model `LogSearchRuleResourcePatch`
  - Added model `LogSettings`
  - Added model `LogSettingsAutoGenerated`
  - Added model `LogToMetricAction`
  - Added model `LogicAppReceiver`
  - Added model `MetadataValue`
  - Added model `Metric`
  - Added model `MetricAlertAction`
  - Added model `MetricAlertCriteria`
  - Added model `MetricAlertMultipleResourceMultipleMetricCriteria`
  - Added model `MetricAlertResource`
  - Added model `MetricAlertResourceCollection`
  - Added model `MetricAlertResourcePatch`
  - Added model `MetricAlertSingleResourceMultipleMetricCriteria`
  - Added model `MetricAlertStatus`
  - Added model `MetricAlertStatusCollection`
  - Added model `MetricAlertStatusProperties`
  - Added model `MetricAvailability`
  - Added model `MetricBaselinesResponse`
  - Added enum `MetricClass`
  - Added model `MetricCriteria`
  - Added model `MetricDefinition`
  - Added model `MetricDefinitionCollection`
  - Added model `MetricDimension`
  - Added model `MetricNamespace`
  - Added model `MetricNamespaceCollection`
  - Added model `MetricNamespaceName`
  - Added model `MetricSettings`
  - Added model `MetricSettingsAutoGenerated`
  - Added model `MetricSingleDimension`
  - Added enum `MetricStatisticType`
  - Added model `MetricTrigger`
  - Added enum `MetricTriggerType`
  - Added enum `MetricUnit`
  - Added model `MetricValue`
  - Added model `MultiMetricCriteria`
  - Added enum `NamespaceClassification`
  - Added model `NotificationRequestBody`
  - Added enum `Odatatype`
  - Added enum `OnboardingStatus`
  - Added model `Operation`
  - Added model `OperationDisplay`
  - Added model `OperationListResult`
  - Added model `OperationStatus`
  - Added enum `Operator`
  - Added model `PerformanceCounterConfiguration`
  - Added model `PredictiveAutoscalePolicy`
  - Added enum `PredictiveAutoscalePolicyScaleMode`
  - Added model `PredictiveResponse`
  - Added model `PredictiveValue`
  - Added model `PrivateEndpointConnection`
  - Added model `PrivateEndpointConnectionListResult`
  - Added model `PrivateEndpointProperty`
  - Added model `PrivateLinkResource`
  - Added model `PrivateLinkResourceListResult`
  - Added model `PrivateLinkScopesResource`
  - Added model `PrivateLinkServiceConnectionStateProperty`
  - Added enum `ProvisioningState`
  - Added model `ProxyOnlyResource`
  - Added model `ProxyResource`
  - Added enum `QueryType`
  - Added model `Recurrence`
  - Added enum `RecurrenceFrequency`
  - Added model `RecurrentSchedule`
  - Added model `Resource`
  - Added model `ResourceAutoGenerated`
  - Added model `ResourceAutoGenerated2`
  - Added model `ResourceAutoGenerated3`
  - Added model `Response`
  - Added model `ResponseWithError`
  - Added enum `ResultType`
  - Added model `RetentionPolicy`
  - Added model `ScaleAction`
  - Added model `ScaleCapacity`
  - Added enum `ScaleDirection`
  - Added model `ScaleRule`
  - Added model `ScaleRuleMetricDimension`
  - Added enum `ScaleRuleMetricDimensionOperationType`
  - Added enum `ScaleType`
  - Added model `Schedule`
  - Added model `ScopedResource`
  - Added model `ScopedResourceListResult`
  - Added model `SenderAuthorization`
  - Added model `ServiceDiagnosticSettingsResource`
  - Added model `ServiceDiagnosticSettingsResourcePatch`
  - Added model `SingleBaseline`
  - Added model `SingleMetricBaseline`
  - Added model `SinkConfiguration`
  - Added enum `SinkConfigurationKind`
  - Added model `Source`
  - Added model `SubscriptionDiagnosticSettingsResource`
  - Added model `SubscriptionDiagnosticSettingsResourceCollection`
  - Added model `SubscriptionLogSettings`
  - Added model `SubscriptionProxyOnlyResource`
  - Added model `SystemData`
  - Added model `TagsResource`
  - Added model `TestNotificationDetailsResponse`
  - Added enum `TimeAggregationType`
  - Added model `TimeSeriesBaseline`
  - Added model `TimeSeriesElement`
  - Added model `TimeWindow`
  - Added model `TriggerCondition`
  - Added model `VMInsightsOnboardingStatus`
  - Added model `WebhookNotification`
  - Added model `WebtestLocationAvailabilityCriteria`
  - Added model `WorkspaceInfo`

### Breaking Changes

  - This package now only targets the latest Api-Version available on Azure and removes APIs of other Api-Version. After this change, the package can have much smaller size. If your application requires a specific and non-latest Api-Version, it's recommended to pin this package to the previous released version; If your application always only use latest Api-Version, please ignore this change.
  - Deleted or renamed client operation group `MonitorManagementClient.tenant_action_groups`
  - Parameter `subscription_id` of client `MonitorManagementClient` is now required
  - Deleted or renamed model `TenantActionGroupList`
  - Deleted or renamed model `TenantActionGroupResource`
  - Deleted or renamed model `TenantActionGroupsOperations`

## 6.0.2 (2023-08-22)

### Bugs Fixed

  - Encode `{}` even if skip_quoto is True  #31346

## 6.0.1 (2023-05-04)

### Other Changes

  - Fixed annotation about namespace

## 6.0.0 (2023-03-20)

### Features Added

  - Added operation MetricDefinitionsOperations.list_at_subscription_scope
  - Added operation MetricsOperations.list_at_subscription_scope
  - Added operation MetricsOperations.list_at_subscription_scope_post
  - Added operation group AzureMonitorWorkspacesOperations
  - Added operation group MonitorOperationsOperations
  - Added operation group TenantActionGroupsOperations
  - Model AzureMonitorPrivateLinkScope has a new parameter system_data
  - Model Condition has a new parameter metric_name
  - Model DataCollectionEndpoint has a new parameter failover_configuration
  - Model DataCollectionEndpoint has a new parameter metadata
  - Model DataCollectionEndpoint has a new parameter metrics_ingestion
  - Model DataCollectionEndpoint has a new parameter private_link_scoped_resources
  - Model DataCollectionEndpointResource has a new parameter failover_configuration
  - Model DataCollectionEndpointResource has a new parameter identity
  - Model DataCollectionEndpointResource has a new parameter metadata
  - Model DataCollectionEndpointResource has a new parameter metrics_ingestion
  - Model DataCollectionEndpointResource has a new parameter private_link_scoped_resources
  - Model DataCollectionEndpointResourceProperties has a new parameter failover_configuration
  - Model DataCollectionEndpointResourceProperties has a new parameter metadata
  - Model DataCollectionEndpointResourceProperties has a new parameter metrics_ingestion
  - Model DataCollectionEndpointResourceProperties has a new parameter private_link_scoped_resources
  - Model DataCollectionRuleAssociationMetadata has a new parameter provisioned_by_resource_id
  - Model DataCollectionRuleDataSources has a new parameter data_imports
  - Model DataCollectionRuleDataSources has a new parameter platform_telemetry
  - Model DataCollectionRuleDataSources has a new parameter prometheus_forwarder
  - Model DataCollectionRuleDataSources has a new parameter windows_firewall_logs
  - Model DataCollectionRuleDestinations has a new parameter event_hubs
  - Model DataCollectionRuleDestinations has a new parameter event_hubs_direct
  - Model DataCollectionRuleDestinations has a new parameter monitoring_accounts
  - Model DataCollectionRuleDestinations has a new parameter storage_accounts
  - Model DataCollectionRuleDestinations has a new parameter storage_blobs_direct
  - Model DataCollectionRuleDestinations has a new parameter storage_tables_direct
  - Model DataCollectionRuleMetadata has a new parameter provisioned_by_resource_id
  - Model DataCollectionRuleResource has a new parameter identity
  - Model DataFlow has a new parameter built_in_transform
  - Model DataSourcesSpec has a new parameter data_imports
  - Model DataSourcesSpec has a new parameter platform_telemetry
  - Model DataSourcesSpec has a new parameter prometheus_forwarder
  - Model DataSourcesSpec has a new parameter windows_firewall_logs
  - Model DestinationsSpec has a new parameter event_hubs
  - Model DestinationsSpec has a new parameter event_hubs_direct
  - Model DestinationsSpec has a new parameter monitoring_accounts
  - Model DestinationsSpec has a new parameter storage_accounts
  - Model DestinationsSpec has a new parameter storage_blobs_direct
  - Model DestinationsSpec has a new parameter storage_tables_direct
  - Model Metadata has a new parameter provisioned_by_resource_id
  - Model Operation has a new parameter action_type
  - Model Operation has a new parameter origin
  - Model PrivateLinkResource has a new parameter required_zone_names
  - Model ResourceForUpdate has a new parameter identity
  - Model ScheduledQueryRuleResource has a new parameter auto_mitigate
  - Model ScheduledQueryRuleResource has a new parameter check_workspace_alerts_storage_configured
  - Model ScheduledQueryRuleResource has a new parameter identity
  - Model ScheduledQueryRuleResource has a new parameter is_workspace_alerts_storage_configured
  - Model ScheduledQueryRuleResource has a new parameter public_network_access
  - Model ScheduledQueryRuleResource has a new parameter rule_resolve_configuration
  - Model ScheduledQueryRuleResource has a new parameter skip_query_validation
  - Model ScheduledQueryRuleResource has a new parameter system_data
  - Model ScheduledQueryRuleResourceCollection has a new parameter next_link
  - Model ScheduledQueryRuleResourcePatch has a new parameter auto_mitigate
  - Model ScheduledQueryRuleResourcePatch has a new parameter check_workspace_alerts_storage_configured
  - Model ScheduledQueryRuleResourcePatch has a new parameter identity
  - Model ScheduledQueryRuleResourcePatch has a new parameter is_workspace_alerts_storage_configured
  - Model ScheduledQueryRuleResourcePatch has a new parameter public_network_access
  - Model ScheduledQueryRuleResourcePatch has a new parameter rule_resolve_configuration
  - Model ScheduledQueryRuleResourcePatch has a new parameter skip_query_validation
  - Model ScopedResource has a new parameter system_data
  - Operation MetricsOperations.list has a new optional parameter auto_adjust_timegrain
  - Operation MetricsOperations.list has a new optional parameter validate_dimensions

### Breaking Changes

  - Model AzureMonitorPrivateLinkScope has a new required parameter access_mode_settings
  - Model Operation no longer has parameter service_specification
  - Model OperationDisplay no longer has parameter publisher
  - Model PrivateEndpointConnectionListResult no longer has parameter next_link
  - Model PrivateLinkResourceListResult no longer has parameter next_link
  - Removed operation ActionGroupsOperations.begin_create_notifications_at_resource_group_level
  - Removed operation ActionGroupsOperations.begin_post_test_notifications
  - Removed operation ActionGroupsOperations.get_test_notifications
  - Removed operation ActionGroupsOperations.get_test_notifications_at_resource_group_level

## 5.0.1 (2022-09-30)

### Bugs Fixed
  
  - Fix paging problem about `api_version`

## 5.0.0 (2022-09-19)

### Features Added

  - Model Resource has a new parameter system_data
  - Model Resource has a new parameter tags

### Breaking Changes

  - Model Resource has a new required parameter location

## 4.0.1 (2022-08-02)

**Other Change**

  - Fix package structure

## 4.0.0 (2022-08-02)

**Features**

  - Added operation ActionGroupsOperations.begin_create_notifications_at_action_group_resource_level
  - Added operation ActionGroupsOperations.begin_create_notifications_at_resource_group_level
  - Added operation ActionGroupsOperations.get_test_notifications_at_action_group_resource_level
  - Added operation ActionGroupsOperations.get_test_notifications_at_resource_group_level

**Breaking changes**

  - Model ActionGroupResource no longer has parameter identity
  - Model ActionGroupResource no longer has parameter kind
  - Model AzureResource no longer has parameter identity
  - Model AzureResource no longer has parameter kind
  - Removed operation group BaselineOperations
  - Removed operation group MetricBaselineOperations

## 3.1.0 (2022-03-16)

**Features**

  - Added operation DataCollectionRuleAssociationsOperations.list_by_data_collection_endpoint
  - Model DataCollectionRule has a new parameter data_collection_endpoint_id
  - Model DataCollectionRule has a new parameter metadata
  - Model DataCollectionRule has a new parameter stream_declarations
  - Model DataCollectionRuleAssociation has a new parameter metadata
  - Model DataCollectionRuleAssociationProxyOnlyResource has a new parameter metadata
  - Model DataCollectionRuleAssociationProxyOnlyResourceProperties has a new parameter metadata
  - Model DataCollectionRuleDataSources has a new parameter iis_logs
  - Model DataCollectionRuleDataSources has a new parameter log_files
  - Model DataCollectionRuleResource has a new parameter data_collection_endpoint_id
  - Model DataCollectionRuleResource has a new parameter metadata
  - Model DataCollectionRuleResource has a new parameter stream_declarations
  - Model DataCollectionRuleResourceProperties has a new parameter data_collection_endpoint_id
  - Model DataCollectionRuleResourceProperties has a new parameter metadata
  - Model DataCollectionRuleResourceProperties has a new parameter stream_declarations
  - Model DataFlow has a new parameter output_stream
  - Model DataFlow has a new parameter transform_kql
  - Model DataSourcesSpec has a new parameter iis_logs
  - Model DataSourcesSpec has a new parameter log_files

## 3.0.0 (2021-11-05)

**Features**

  - Model LogAnalyticsDestination has a new parameter workspace_id
  - Model LogSettings has a new parameter category_group
  - Model Baseline has a new parameter timestamps
  - Model Baseline has a new parameter error_type
  - Model Baseline has a new parameter prediction_result_type
  - Model Metric has a new parameter error_message
  - Model Metric has a new parameter error_code
  - Model Metric has a new parameter display_description
  - Model ManagementGroupDiagnosticSettingsResource has a new parameter system_data
  - Model ManagementGroupDiagnosticSettingsResource has a new parameter marketplace_partner_id
  - Model DataCollectionRuleAssociationProxyOnlyResourceProperties has a new parameter data_collection_endpoint_id
  - Model SubscriptionDiagnosticSettingsResource has a new parameter system_data
  - Model SubscriptionDiagnosticSettingsResource has a new parameter marketplace_partner_id
  - Model TimeSeriesBaseline has a new parameter metadata_values
  - Model DataCollectionRuleAssociationProxyOnlyResource has a new parameter system_data
  - Model DataCollectionRuleAssociationProxyOnlyResource has a new parameter data_collection_endpoint_id
  - Model CalculateBaselineResponse has a new parameter internal_operation_id
  - Model CalculateBaselineResponse has a new parameter statistics
  - Model CalculateBaselineResponse has a new parameter error_type
  - Model DataCollectionRule has a new parameter immutable_id
  - Model AlertRuleResourcePatch has a new parameter provisioning_state
  - Model AlertRuleResourcePatch has a new parameter action
  - Model OperationDisplay has a new parameter description
  - Model OperationDisplay has a new parameter publisher
  - Model ManagementGroupLogSettings has a new parameter category_group
  - Model SubscriptionLogSettings has a new parameter category_group
  - Model DiagnosticSettingsCategoryResource has a new parameter system_data
  - Model DiagnosticSettingsCategoryResource has a new parameter category_groups
  - Model BaselineResponse has a new parameter internal_operation_id
  - Model BaselineResponse has a new parameter metdata
  - Model BaselineResponse has a new parameter error_type
  - Model BaselineResponse has a new parameter prediction_result_type
  - Model ActionGroupResource has a new parameter event_hub_receivers
  - Model ActionGroupResource has a new parameter kind
  - Model ActionGroupResource has a new parameter identity
  - Model AutoscaleSettingResource has a new parameter system_data
  - Model AutoscaleSettingResource has a new parameter predictive_autoscale_policy
  - Model AutoscaleSettingResource has a new parameter target_resource_location
  - Model ScheduledQueryRuleResourcePatch has a new parameter is_legacy_log_analytics_rule
  - Model ScheduledQueryRuleResourcePatch has a new parameter override_query_time_range
  - Model ScheduledQueryRuleResourcePatch has a new parameter display_name
  - Model ScheduledQueryRuleResourcePatch has a new parameter created_with_api_version
  - Model ExtensionDataSource has a new parameter input_data_sources
  - Model LogSearchRuleResource has a new parameter created_with_api_version
  - Model LogSearchRuleResource has a new parameter kind
  - Model LogSearchRuleResource has a new parameter auto_mitigate
  - Model LogSearchRuleResource has a new parameter display_name
  - Model LogSearchRuleResource has a new parameter etag
  - Model LogSearchRuleResource has a new parameter is_legacy_log_analytics_rule
  - Model AutoscaleSettingResourcePatch has a new parameter predictive_autoscale_policy
  - Model AutoscaleSettingResourcePatch has a new parameter target_resource_location
  - Model RuleDataSource has a new parameter resource_location
  - Model RuleDataSource has a new parameter metric_namespace
  - Model RuleDataSource has a new parameter legacy_resource_id
  - Model AlertRuleResource has a new parameter provisioning_state
  - Model AlertRuleResource has a new parameter action
  - Model Operation has a new parameter service_specification
  - Model Operation has a new parameter is_data_action
  - Model MetricDefinition has a new parameter metric_class
  - Model MetricDefinition has a new parameter category
  - Model MetricDefinition has a new parameter display_description
  - Model DataCollectionRuleAssociation has a new parameter data_collection_endpoint_id
  - Model MetricTrigger has a new parameter metric_resource_location
  - Model MetricTrigger has a new parameter divide_per_instance
  - Model MetricAlertResource has a new parameter is_migrated
  - Model RuleManagementEventDataSource has a new parameter resource_location
  - Model RuleManagementEventDataSource has a new parameter metric_namespace
  - Model RuleManagementEventDataSource has a new parameter legacy_resource_id
  - Model MetricAlertResourcePatch has a new parameter is_migrated
  - Model ScheduledQueryRuleResource has a new parameter created_with_api_version
  - Model ScheduledQueryRuleResource has a new parameter kind
  - Model ScheduledQueryRuleResource has a new parameter etag
  - Model ScheduledQueryRuleResource has a new parameter display_name
  - Model ScheduledQueryRuleResource has a new parameter is_legacy_log_analytics_rule
  - Model ScheduledQueryRuleResource has a new parameter override_query_time_range
  - Model RuleMetricDataSource has a new parameter resource_location
  - Model RuleMetricDataSource has a new parameter metric_namespace
  - Model RuleMetricDataSource has a new parameter legacy_resource_id
  - Model DiagnosticSettingsResource has a new parameter system_data
  - Model DiagnosticSettingsResource has a new parameter marketplace_partner_id
  - Model MetricNamespace has a new parameter classification
  - Model DataCollectionRuleResource has a new parameter system_data
  - Model DataCollectionRuleResource has a new parameter immutable_id
  - Model DataCollectionRuleResource has a new parameter kind
  - Model DataCollectionRuleResourceProperties has a new parameter immutable_id
  - Added operation ActionGroupsOperations.begin_post_test_notifications
  - Added operation ActionGroupsOperations.get_test_notifications
  - Added operation group PredictiveMetricOperations
  - Added operation group DataCollectionEndpointsOperations

**Breaking changes**

  - Parameter scopes of model MetricAlertResource is now required
  - Operation ActivityLogAlertsOperations.update has a new signature
  - Operation ActivityLogAlertsOperations.create_or_update has a new signature
  - Operation SubscriptionDiagnosticSettingsOperations.list has a new signature
  - Operation SubscriptionDiagnosticSettingsOperations.get has a new signature
  - Operation SubscriptionDiagnosticSettingsOperations.delete has a new signature
  - Operation SubscriptionDiagnosticSettingsOperations.create_or_update has a new signature
  - Model PerfCounterDataSource no longer has parameter scheduled_transfer_period
  - Model ManagementGroupDiagnosticSettingsResource no longer has parameter location
  - Model SubscriptionDiagnosticSettingsResource no longer has parameter location
  - Model TimeSeriesBaseline no longer has parameter metadata
  - Model ErrorResponse no longer has parameter target
  - Model ErrorResponse no longer has parameter details
  - Model ErrorResponse no longer has parameter additional_info
  - Model WindowsEventLogDataSource no longer has parameter scheduled_transfer_period
  - Model BaselineResponse no longer has parameter metadata


## 2.0.0 (2020-12-25)

**Breaking changes**

- Client name changed from MonitorClient to MonitorManagementClient

## 1.0.1 (2020-09-18)

**Bug fix**

  - Require azure-mgmt-core>=1.2.0 in setup.py

## 1.0.0 (2020-09-16)

**Features**

  - Model MultiMetricCriteria has a new parameter skip_metric_validation
  - Model DynamicMetricCriteria has a new parameter skip_metric_validation
  - Model MetricTrigger has a new parameter dimensions
  - Model MetricTrigger has a new parameter metric_namespace
  - Model MetricCriteria has a new parameter skip_metric_validation
  - Added operation group SubscriptionDiagnosticSettingsOperations
  - Added operation group ManagementGroupDiagnosticSettingsOperations

## 1.0.0b1 (2020-06-17)

This is beta preview version.

This version uses a next-generation code generator that introduces important breaking changes, but also important new features (like unified authentication and async programming).

**General breaking changes**

- Credential system has been completly revamped:

  - `azure.common.credentials` or `msrestazure.azure_active_directory` instances are no longer supported, use the `azure-identity` classes instead: https://pypi.org/project/azure-identity/
  - `credentials` parameter has been renamed `credential`

- The `config` attribute no longer exists on a client, configuration should be passed as kwarg. Example: `MyClient(credential, subscription_id, enable_logging=True)`. For a complete set of
  supported options, see the [parameters accept in init documentation of azure-core](https://github.com/Azure/azure-sdk-for-python/blob/main/sdk/core/azure-core/CLIENT_LIBRARY_DEVELOPER.md#available-policies)
- You can't import a `version` module anymore, use `__version__` instead
- Operations that used to return a `msrest.polling.LROPoller` now returns a `azure.core.polling.LROPoller` and are prefixed with `begin_`.
- Exceptions tree have been simplified and most exceptions are now `azure.core.exceptions.HttpResponseError` (`CloudError` has been removed).
- Most of the operation kwarg have changed. Some of the most noticeable:

  - `raw` has been removed. Equivalent feature can be found using `cls`, a callback that will give access to internal HTTP response for advanced user
  - For a complete set of
  supported options, see the [parameters accept in Request documentation of azure-core](https://github.com/Azure/azure-sdk-for-python/blob/main/sdk/core/azure-core/CLIENT_LIBRARY_DEVELOPER.md#available-policies)

**General new features**

- Type annotations support using `typing`. SDKs are mypy ready.
- This client has now stable and official support for async. Check the `aio` namespace of your package to find the async client.
- This client now support natively tracing library like OpenCensus or OpenTelemetry. See this [tracing quickstart](https://github.com/Azure/azure-sdk-for-python/tree/main/sdk/core/azure-core-tracing-opentelemetry) for an overview.


## 0.10.0 (2020-06-08)

**Features**

  - Model WebtestLocationAvailabilityCriteria has a new parameter additional_properties
  - Added operation group SubscriptionDiagnosticSettingsOperations

**Breaking changes**

  - Model WebtestLocationAvailabilityCriteria has a new required parameter odatatype

## 0.9.0 (2020-04-09)

**Features**

  - Model AzureMonitorPrivateLinkScope has a new parameter private_endpoint_connections

**Breaking changes**

  - Operation PrivateLinkScopedResourcesOperations.create_or_update has a new signature
  - Model PrivateEndpointConnection no longer has parameter tags
  - Model PrivateLinkResource no longer has parameter tags
  - Model ScopedResource no longer has parameter tags
  - Model ProxyResource no longer has parameter tags
  - Operation PrivateEndpointConnectionsOperations.create_or_update has a new signature
  - Model ErrorResponse has a new signature

## 0.8.0 (2020-03-14)

**Features**

- Model DiagnosticSettingsResource has a new parameter log_analytics_destination_type
- Model ProxyResource has a new parameter tags
- Model MetricAlertAction has a new parameter web_hook_properties
- Added operation group PrivateEndpointConnectionsOperations
- Added operation group PrivateLinkScopedResourcesOperations
- Added operation group PrivateLinkScopeOperationStatusOperations
- Added operation group PrivateLinkResourcesOperations
- Added operation group PrivateLinkScopesOperations

**Breaking changes**

- Model MetricAlertAction no longer has parameter webhook_properties
- Model ErrorResponse has a new signature


## 0.7.0 (2019-06-24)

This package now support profiles as parameter for sovereign cloud
support

**Features**

  - Model MultiMetricCriteria has a new parameter metric_namespace
  - Model MultiMetricCriteria has a new parameter dimensions
  - Added operation group ServiceDiagnosticSettingsOperations
  - Added operation group GuestDiagnosticsSettingsOperations
  - Added operation group BaselinesOperations
  - Added operation group GuestDiagnosticsSettingsAssociationOperations
  - Added operation group BaselineOperations

**Breaking changes**

  - Operation MetricBaselineOperations.get has a new signature
  - Model MultiMetricCriteria has a new required parameter name
  - Model MultiMetricCriteria has a new required parameter
    time_aggregation
  - Model MultiMetricCriteria has a new required parameter metric_name
  - Model ArmRoleReceiver has a new required parameter
    use_common_alert_schema
  - Model LogicAppReceiver has a new required parameter
    use_common_alert_schema
  - Model AzureFunctionReceiver has a new required parameter
    use_common_alert_schema
  - Model EmailReceiver has a new required parameter
    use_common_alert_schema
  - Model AutomationRunbookReceiver has a new required parameter
    use_common_alert_schema
  - Model WebhookReceiver has a new signature

**General Breaking changes**

This version uses a next-generation code generator that *might*
introduce breaking changes for some imports. In summary, some modules
were incorrectly visible/importable and have been renamed. This fixed
several issues caused by usage of classes that were not supposed to be
used in the first place.

  - MonitorManagementClient cannot be imported from
    `azure.mgmt.monitor.monitor_management_client` anymore (import
    from `azure.mgmt.monitor` works like before)
  - MonitorManagementClientConfiguration import has been moved from
    `azure.mgmt.monitor.monitor_management_client` to
    `azure.mgmt.monitor`
  - A model `MyClass` from a "models" sub-module cannot be imported
    anymore using `azure.mgmt.monitor.models.my_class` (import from
    `azure.mgmt.monitor.models` works like before)
  - An operation class `MyClassOperations` from an `operations`
    sub-module cannot be imported anymore using
    `azure.mgmt.monitor.operations.my_class_operations` (import from
    `azure.mgmt.monitor.operations` works like before)

Last but not least, HTTP connection pooling is now enabled by default.
You should always use a client as a context manager, or call close(), or
use no more than one client per process.

## 0.6.0 (2018-03-06)

**Features**

  - Model MetricCriteria has a new parameter additional_properties
  - Model MetricAlertResource has a new parameter
    target_resource_region
  - Model MetricAlertResource has a new parameter target_resource_type
  - Model MetricAlertResourcePatch has a new parameter
    target_resource_region
  - Model MetricAlertResourcePatch has a new parameter
    target_resource_type
  - Model ActionGroupResource has a new parameter arm_role_receivers
  - Model DiagnosticSettingsResource has a new parameter
    service_bus_rule_id
  - Added operation AutoscaleSettingsOperations.list_by_subscription
  - Added operation AlertRulesOperations.list_by_subscription
  - Added operation group MetricNamespacesOperations
  - Added operation group VMInsightsOperations

**Breaking changes**

  - Model MetricCriteria has a new required parameter criterion_type

## 0.5.2 (2018-06-06)

**Features**

  - Model ActionGroupResource has a new parameter voice_receivers
  - Model ActionGroupResource has a new parameter
    azure_function_receivers
  - Model ActionGroupResource has a new parameter logic_app_receivers
  - Added operation group MetricAlertsOperations
  - Added operation group ScheduledQueryRulesOperations
  - Added operation group MetricAlertsStatusOperations

## 0.5.1 (2018-04-16)

**Bugfixes**

  - Fix some invalid models in Python 3
  - Compatibility of the sdist with wheel 0.31.0

## 0.5.0 (2017-03-19)

**General Breaking changes**

This version uses a next-generation code generator that *might*
introduce breaking changes.

  - Model signatures now use only keyword-argument syntax. All
    positional arguments must be re-written as keyword-arguments. To
    keep auto-completion in most cases, models are now generated for
    Python 2 and Python 3. Python 3 uses the "*" syntax for
    keyword-only arguments.
  - Enum types now use the "str" mixin (class AzureEnum(str, Enum)) to
    improve the behavior when unrecognized enum values are encountered.
    While this is not a breaking change, the distinctions are important,
    and are documented here:
    <https://docs.python.org/3/library/enum.html#others> At a glance:
      - "is" should not be used at all.
      - "format" will return the string value, where "%s" string
        formatting will return `NameOfEnum.stringvalue`. Format syntax
        should be prefered.
  - New Long Running Operation:
      - Return type changes from
        `msrestazure.azure_operation.AzureOperationPoller` to
        `msrest.polling.LROPoller`. External API is the same.
      - Return type is now **always** a `msrest.polling.LROPoller`,
        regardless of the optional parameters used.
      - The behavior has changed when using `raw=True`. Instead of
        returning the initial call result as `ClientRawResponse`,
        without polling, now this returns an LROPoller. After polling,
        the final resource will be returned as a `ClientRawResponse`.
      - New `polling` parameter. The default behavior is
        `Polling=True` which will poll using ARM algorithm. When
        `Polling=False`, the response of the initial call will be
        returned without polling.
      - `polling` parameter accepts instances of subclasses of
        `msrest.polling.PollingMethod`.
      - `add_done_callback` will no longer raise if called after
        polling is finished, but will instead execute the callback right
        away.

**Bugfixes**

  - Fix invalid type of "top" in metrics.list operation

**Features**

  - New operation group metric_baseline
  - Add attribute action_group_resource itsm_receivers
  - Add operation action_groups.update
  - Add new parameter "metricnames" to metrics.list
  - Add new parameter "metricnamespace" to metrics.list
  - All operations group have now a "models" attribute

New ApiVersion version of metrics to 2018-01-01

## 0.4.0 (2017-10-25)

**Features**

  - Merge into this package the "azure-monitor" package including
    following operations groups
      - event categories
      - activity log
      - tenant activity log
      - metrics definitions
      - metrics
  - Adding new multi-dimensional metrics API

**Breaking changes**

  - Some exceptions have moved from CloudError to ErrorResponseException
  - "service_diagnostic_settings" renamed to "diagnostic_settings"
  - Update API version of "metrics". Migrating from "azure-monitor" to
    "metrics" here needs to be rewritten.

**Bug fixes**

  - Improving HTTP status code check for better exception

## 0.3.0 (2017-06-30)

**Features**

  - Add action_groups operation group
  - Add alert_rules.update method
  - Add autoscale_settings.update method
  - Add log_profiles.update method

**Breaking changes**

  - activity_log_alerts.update has now flatten parameters
    "tags/enabled"

## 0.2.1 (2017-04-26)

  - Removal of a REST endpoint not ready to release.

## 0.2.0 (2017-04-19)

  - Add ActivityLogAlerts and DiagnosticSettings
  - Minor improvements, might be breaking
  - This wheel package is now built with the azure wheel extension

## 0.1.0 (2017-02-16)

  - Initial Release
